@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2007, 2008 by Carsten Niehaus <cniehaus@kde.org>        *
- *   Copyright (C) 2006 by Georges Khaznadar                               *
+ *   Copyright (C) 2006 by Georges Khaznadar <georgesk@debian.org>         *
  *   Copyright (C) 2006, 2007 by Jerome Pansanel <j.pansanel@pansanel.net> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,12 +26,12 @@
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QFileDialog>
-#include <QLinkedList>
 #include <QProcess>
 #include <QPushButton>
 #include <QRegularExpression>
 #include <QUrl>
 #include <QVBoxLayout>
+#include <QVector>
 
 // KDE includes
 #include <KConfigGroup>
@@ -204,7 +204,7 @@ void KOpenBabel::slotConvert()
     }
     QListIterator<QListWidgetItem*> it(p);
     QStringList cmdList; // Full command
-    QLinkedList<QStringList> cmdArgList; // Arguments only
+    QVector<QStringList> cmdArgList; // Arguments only
     foreach (QListWidgetItem * item, p) {
         QString ifname = QUrl(item->text()).toLocalFile();
         QString ofname = ifname;
